@@ -53,7 +53,8 @@ class VaspErrorHandler(ErrorHandler, MSONable):
         "too_few_bands": ["TOO FEW BANDS"],
         "triple_product": ["ERROR: the triple product of the basis vectors"],
         "rot_matrix": ["Found some non-integer element in rotation matrix"],
-        "brions": ["BRIONS problems: POTIM should be increased"]
+        "brions": ["BRIONS problems: POTIM should be increased"],
+        "pricel": ["internal error in subroutine PRICEL"]
     }
 
     def __init__(self, output_filename="vasp.out"):
@@ -83,7 +84,7 @@ class VaspErrorHandler(ErrorHandler, MSONable):
                             "action": {"_set": {"SYMPREC": 1e-8}}})
         if "brmix" in self.errors:
             actions.append({"dict": "INCAR",
-                            "action": {"_set": {"IMIX": 1}}})
+                            "action": {"_set": {"ISYM": 0}}})
         if "subspacematrix" in self.errors or "rspher" in self.errors or \
                 "real_optlay" in self.errors:
             actions.append({"dict": "INCAR",
@@ -95,17 +96,17 @@ class VaspErrorHandler(ErrorHandler, MSONable):
             if "NBANDS" in vi["INCAR"]:
                 nbands = int(vi["INCAR"]["NBANDS"])
             else:
-                with open("OUTCAR", "r") as f:
+                with open("OUTCAR") as f:
                     for line in f:
                         if "NBANDS" in line:
                             try:
                                 d = line.split("=")
                                 nbands = int(d[-1].strip())
                                 break
-                            except:
+                            except (IndexError, ValueError):
                                 pass
             actions.append({"dict": "INCAR",
-                            "action": {"_set": {"NBANDS": int(1.2 * nbands)}}})
+                            "action": {"_set": {"NBANDS": int(1.1 * nbands)}}})
 
         if "triple_product" in self.errors:
             s = vi["POSCAR"].structure
@@ -115,13 +116,14 @@ class VaspErrorHandler(ErrorHandler, MSONable):
                             "action": {"_set": {"structure": new_s.to_dict}},
                             "transformation": trans.to_dict})
 
-        if "rot_matrix" in self.errors:
+        if "rot_matrix" in self.errors or "pricel" in self.errors:
             s = vi["POSCAR"].structure
             trans = PerturbStructureTransformation(0.05)
             new_s = trans.apply_transformation(s)
             actions.append({"dict": "POSCAR",
                             "action": {"_set": {"structure": new_s.to_dict}},
                             "transformation": trans.to_dict})
+
         if "brions" in self.errors:
             potim = vi["INCAR"].get("POTIM", 0.5) + 0.1
             actions.append({"dict": "INCAR",
@@ -148,9 +150,9 @@ class VaspErrorHandler(ErrorHandler, MSONable):
                 "@class": self.__class__.__name__,
                 "output_filename": self.output_filename}
 
-    @staticmethod
-    def from_dict(d):
-        return VaspErrorHandler(d["output_filename"])
+    @classmethod
+    def from_dict(cls, d):
+        return cls(d["output_filename"])
 
 
 class MeshSymmetryErrorHandler(ErrorHandler, MSONable):
@@ -160,14 +162,16 @@ class MeshSymmetryErrorHandler(ErrorHandler, MSONable):
     and if the run has converged, no error is recorded.
     """
 
-    def __init__(self, output_filename="vasp.out"):
+    def __init__(self, output_filename="vasp.out",
+                 output_vasprun="vasprun.xml"):
         self.output_filename = output_filename
+        self.output_vasprun = output_vasprun
 
     def check(self):
         msg = "Reciprocal lattice and k-lattice belong to different class of" \
               " lattices."
         try:
-            v = Vasprun(self.output_filename)
+            v = Vasprun(self.output_vasprun)
             if v.converged:
                 return False
         except:
@@ -208,11 +212,13 @@ class MeshSymmetryErrorHandler(ErrorHandler, MSONable):
     def to_dict(self):
         return {"@module": self.__class__.__module__,
                 "@class": self.__class__.__name__,
-                "output_filename": self.output_filename}
+                "output_filename": self.output_filename,
+                "output_vasprun": self.output_vasprun}
 
-    @staticmethod
-    def from_dict(d):
-        return MeshSymmetryErrorHandler(d["output_filename"])
+    @classmethod
+    def from_dict(cls, d):
+        return cls(output_filename=d["output_filename"],
+                   output_vasprun=d["output_vasprun"])
 
 
 class UnconvergedErrorHandler(ErrorHandler, MSONable):
@@ -266,9 +272,9 @@ class UnconvergedErrorHandler(ErrorHandler, MSONable):
                 "@class": self.__class__.__name__,
                 "output_filename": self.output_filename}
 
-    @staticmethod
-    def from_dict(d):
-        return UnconvergedErrorHandler(d["output_filename"])
+    @classmethod
+    def from_dict(cls, d):
+        return cls(d["output_filename"])
 
 
 class FrozenJobErrorHandler(ErrorHandler):
@@ -314,10 +320,9 @@ class FrozenJobErrorHandler(ErrorHandler):
                 "output_filename": self.output_filename,
                 "timeout": self.timeout}
 
-    @staticmethod
-    def from_dict(d):
-        return FrozenJobErrorHandler(d["output_filename"],
-                                     timeout=d["timeout"])
+    @classmethod
+    def from_dict(cls, d):
+        return cls(d["output_filename"], timeout=d["timeout"])
 
 
 class NonConvergingErrorHandler(ErrorHandler, MSONable):
@@ -354,9 +359,9 @@ class NonConvergingErrorHandler(ErrorHandler, MSONable):
                 "@class": self.__class__.__name__,
                 "output_filename": self.output_filename}
 
-    @staticmethod
-    def from_dict(d):
-        return NonConvergingErrorHandler(d["output_filename"])
+    @classmethod
+    def from_dict(cls, d):
+        return cls(d["output_filename"])
 
 
 def backup():
